@@ -20,14 +20,13 @@ from pyquanda.environment import (
     INTERVIEW_CONFIG_REMOTE_FILE,
     MOCK_CONFIG,
     DEMO_DIR,
+    InterviewConfig,
 )
 from pyquanda.exceptions import PreCheckFail
 from pyquanda.host.question_data import QuestionCollection
 from pyquanda.host.main_intro_data import MainIntroCollection
 from pyquanda.host.userdata import UserDataScript
 
-BASE_YAML = Path("/tmp/interview.yaml")
-
 
 XONSH_FILE = Path("~/.xonshrc").expanduser()
 XONSH_TXT = """
@@ -53,6 +52,18 @@ def yesno(question: str) -> bool:
     return False
 
 
+def _config_replace_if_arg_given(src_config: str):
+    """If defined in an argument, replace the the default runtime with the given path."""
+    path = Path(src_config)
+    if path == INTERVIEW_CONFIG_REMOTE_FILE:
+        return
+    if not path.exists():
+        raise PreCheckFail(f"{path} does not exist")
+    # kick the file to make sure it's valid
+    shutil.copy(src_config, INTERVIEW_CONFIG_REMOTE_FILE)
+    InterviewConfig().as_dict()
+
+
 class CreateNewModule:
     """CreateNewModule."""
 
@@ -73,19 +84,16 @@ class CreateNewModule:
         _pwrap.add_arg_type()
         _pwrap.add_arg_name()
         _pwrap.add_arg_description()
-        _pwrap.add_no_overwrite()
+        _pwrap.add_overwrite()
         _pwrap.add_destination_directory(default=".", required=True)
         self.parser = _pwrap.parser
 
     @staticmethod
     def create_new_module(args: argparse.Namespace):
         """Run main function."""
-        try:
-            dst = Path(args.destination_directory)
-            copy_type(args.type, dst, args.name, args.description)
-            print(f"{dst.absolute()} created!")
-        except PreCheckFail as _e:
-            raise SystemExit(_e) from _e
+        dst = Path(args.destination_directory)
+        copy_type(args.type, dst, args.name, args.description)
+        print(f"{dst.absolute()} created!")
 
 
 class RunModule:
@@ -106,7 +114,9 @@ class RunModule:
             "run ansible on a single module based on path",
             self.run,
         )
+        _pwrap.add_interview_config()
         _pwrap.add_src_module_directory()
+        _pwrap.add_debug()
         self.parser = _pwrap.parser
 
     @staticmethod
@@ -117,8 +127,9 @@ class RunModule:
             args (argparse.Namespace): args
         """
         src = Path(args.src_module_dir)
-        obj = Ansible(src)
-        obj.run()
+        if args.interview_config_yaml:
+            _config_replace_if_arg_given(args.interview_config_yaml)
+        Ansible.run_single(src, args.debug)
 
 
 class RunAllModules:
@@ -140,7 +151,9 @@ class RunAllModules:
             self.run,
         )
         self.parser = _pwrap.parser
+        _pwrap.add_interview_config()
         _pwrap.add_src_module_directory()
+        _pwrap.add_debug()
 
     @staticmethod
     def run(args: argparse.Namespace):
@@ -149,16 +162,10 @@ class RunAllModules:
         Args:
             args (argparse.Namespace): args
         """
+        if args.interview_config_yaml:
+            _config_replace_if_arg_given(args.interview_config_yaml)
         mod_path = Path(args.src_module_dir)
-        collection = []
-        for i in mod_path.iterdir():
-            if not i.is_dir():
-                continue
-            ans = Ansible(i)
-            collection.append(ans)
-
-        for mod in collection:
-            mod.run()
+        Ansible.run_all(mod_path, args.debug)
 
 
 class AssembleQuestions:
@@ -179,6 +186,7 @@ class AssembleQuestions:
             "convert questions to pyquanda questions config file",
             self.run,
         )
+        _pwrap.add_interview_config()
         _pwrap.add_src_module_directory()
         _pwrap.add_destination_directory(
             required=False, default=str(QUESTIONS_DATA.parent)
@@ -192,10 +200,10 @@ class AssembleQuestions:
         Args:
             args (argparse.Namespace): args
         """
+        if args.interview_config_yaml:
+            _config_replace_if_arg_given(args.interview_config_yaml)
         base_mod_path = Path(args.src_module_dir)
         for mod_path in base_mod_path.iterdir():
-            if not mod_path.is_dir():
-                continue
             ModuleLoader.load(mod_path)
         HookLoader.load()
         QuestionCollection.export()
@@ -220,6 +228,7 @@ class TestQuestions:
             self.run,
         )
         _pwrap.add_src_module_directory()
+        _pwrap.add_interview_config()
         self.parser = _pwrap.parser
         self.parser.add_argument(
             "--keep_state",
@@ -239,6 +248,8 @@ class TestQuestions:
         Raises:
             SystemExit: if there is an issue
         """
+        if args.interview_config_yaml:
+            _config_replace_if_arg_given(args.interview_config_yaml)
         args.destination_directory = QUESTIONS_DATA.parent
         AssembleQuestions.run(args)
         if not XONSH_FILE.exists():
@@ -270,6 +281,8 @@ class Demo:
             self.run,
         )
         parser = _pwrap.parser
+        _pwrap.add_destination_directory(required=False)
+        _pwrap.add_overwrite()
         parser.add_argument("--hidden", help=argparse.SUPPRESS, default=None)
 
     @staticmethod
@@ -279,17 +292,43 @@ class Demo:
         Args:
             args (argparse.Namespace): args
         """
+        INTERVIEW_CONFIG_REMOTE_FILE.write_text(MOCK_CONFIG)
         if INTERVIEW_STATE_REMOTE_FILE.exists():
             INTERVIEW_STATE_REMOTE_FILE.unlink()
-        INTERVIEW_CONFIG_REMOTE_FILE.write_text(MOCK_CONFIG)
         args.destination_directory = QUESTIONS_DATA.parent
         args.src_module_dir = DEMO_DIR
+        args.interview_config_yaml = INTERVIEW_CONFIG_REMOTE_FILE
         AssembleQuestions.run(args)
         with tempfile.TemporaryDirectory() as tdir:
             tempdir = Path(tdir)
+            shutil.copytree(args.src_module_dir, tempdir.joinpath("modules"))
+            shutil.copy(
+                args.interview_config_yaml,
+                tempdir.joinpath(args.interview_config_yaml.name),
+            )
             xonrc = tempdir.joinpath("xonshrc")
             xonrc.write_text(XONSH_TXT)
-            os.system(f"xonsh --rc {xonrc}")
+            xonsh_cmd = f"xonsh --rc {xonrc}"
+            os.system(xonsh_cmd)
+            ddir = args.destination_directory.joinpath(
+                "pyquanda_demo"
+            ).absolute()
+            save_msg = [
+                "Edit / run this again with",
+                f"pyquanda-cmd q_test -s {ddir}/modules -c"
+                f" {ddir}/interview.yaml",
+            ]
+            if ddir.exists():
+                if not args.overwrite:
+                    print(
+                        f"{args.destination_directory} exists, set"
+                        " --overwrite if you would like to overwrite"
+                    )
+                    return
+                shutil.rmtree(ddir)
+            shutil.copytree(tempdir, ddir)
+            print(f"Demo saved to: {ddir}")
+            print("\n".join(save_msg))
 
 
 class SaveUserData:
@@ -310,6 +349,7 @@ class SaveUserData:
             "save userdata zip file in directory (filename: userdata.zip)",
             self.run,
         )
+        _pwrap.add_interview_config(required=True)
         _pwrap.add_src_module_directory()
         _pwrap.add_destination_directory(required=True)
         self.parser = _pwrap.parser
@@ -321,12 +361,13 @@ class SaveUserData:
         Args:
             args (argparse.Namespace): args
         """
-        with UserDataScript(args.src_module_dir) as udata:
-            dest_dir = Path(args.destination_directory)
+        with UserDataScript(
+            args.src_module_dir, args.interview_config_yaml
+        ) as udata:
+            ddir = Path(args.destination_directory)
+            dest_file = ddir.joinpath("userdata.zip")
             zfile = udata.zipfile()
-            dest_file = dest_dir.joinpath(zfile.name)
             shutil.copy(zfile, dest_file)
-
             print(f"{dest_file.absolute()} saved!")
 
 
@@ -371,10 +412,15 @@ class Bootstrap:
 
         ns = argparse.Namespace()
         ns.src_module_dir = str(REMOTE_BASE_PATH)
+        ns.interview_config_yaml = str(INTERVIEW_CONFIG_REMOTE_FILE)
+        ns.debug = False
         AssembleQuestions.run(ns)
         RunAllModules.run(ns)
         pzip.unlink()
-        shutil.rmtree(REMOTE_BASE_PATH)
+        for i in REMOTE_BASE_PATH.iterdir():
+            if i.name == "_hooks":
+                continue
+            shutil.rmtree(i)
         tmpdir = Path("/tmp")
         for i in tmpdir.iterdir():
             if i.name.startswith("tmp"):
