@@ -5,13 +5,11 @@
 import time
 from abc import ABC, abstractmethod
 from typing import Dict
+from pyquanda.lib.yaml_util import load_from_path
 
-from ruamel.yaml.main import YAML
 
 from pyquanda.environment import INTERVIEW_CONFIG_REMOTE_FILE
 
-yaml = YAML()
-
 
 class Hook(ABC):
     """BaseHookType."""
@@ -27,10 +25,10 @@ class Hook(ABC):
             None:
         """
         self.name = name
-        _config = yaml.load(INTERVIEW_CONFIG_REMOTE_FILE)  # type: Dict
-        _config.pop("hooks")
-        _config.update(config)
-        self.config = _config
+        self.vars = load_from_path(INTERVIEW_CONFIG_REMOTE_FILE)  # type: Dict
+        if "hooks" in self.vars:
+            del self.vars["hooks"]
+        self.config = config
 
     def fmt_json(self, dct: Dict) -> Dict:
         """fmt_json.
@@ -43,11 +41,20 @@ class Hook(ABC):
         """
         return {
             "ts": str(time.time()),
+            "vars": self.vars,
             "type": self.name,
             "config": self.config,
             "event": dct,
         }
 
+    @abstractmethod
+    async def async_send(self, dct: Dict):
+        """send.
+
+        Args:
+            dct (Dict): dct
+        """
+
     @abstractmethod
     def send(self, dct: Dict):
         """send.
